==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/villager/Priest.java <==
package cc.thonly.reverie_dreams.entity.villager;

import cc.thonly.reverie_dreams.item.ModItems;
import net.fabricmc.fabric.api.object.builder.v1.trade.TradeOfferHelper;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1887;
import net.minecraft.class_1893;
import net.minecraft.class_1914;
import net.minecraft.class_2378;
import net.minecraft.class_5455;
import net.minecraft.class_7924;
import net.minecraft.class_9306;
import java.util.Optional;

public class Priest {
    public static void registers() {
        TradeOfferHelper.registerVillagerOffers(ModVillagerProfessions.PRIEST, 1, factories -> {
            factories.add((entity, random) -> new class_1914(
                            new class_9306(ModItems.POWER, 11),
                            Optional.empty(),
                            new class_1799(ModItems.COPPER_COIN, 3),
                            7,
                            5,
                            0.2f
                    )
            );
            factories.add((entity, random) -> new class_1914(
                            new class_9306(ModItems.POINT, 12),
                            Optional.empty(),
                            new class_1799(ModItems.COPPER_COIN, 3),
                            7,
                            5,
                            0.13f
                    )
            );
        });
        TradeOfferHelper.registerVillagerOffers(ModVillagerProfessions.PRIEST, 2, factories -> {
            factories.add((entity, random) -> new class_1914(
                            new class_9306(ModItems.POWER, 38),
                            Optional.of(new class_9306(ModItems.COPPER_COIN, 24)),
                            new class_1799(ModItems.EXORCISM_PAPER, 6),
                            4,
                            5,
                            0.2f
                    )
            );
            factories.add((entity, random) -> {
                class_5455 registryManager = entity.method_56673();
                class_1799 woodenSwordStack = class_1802.field_8091.method_7854();
                class_2378<class_1887> lookup = registryManager.method_30530(class_7924.field_41265);
                woodenSwordStack.method_7978(lookup.method_47983(lookup.method_29107(class_1893.field_9123)), 4);
                woodenSwordStack.method_7978(lookup.method_47983(lookup.method_29107(class_1893.field_9119)), 2);
                return new class_1914(
                        new class_9306(ModItems.POINT, 29),
                        Optional.of(new class_9306(ModItems.COPPER_COIN, 31)),
                        woodenSwordStack,
                        7,
                        5,
                        0.13f
                );
            });
            factories.add((entity, random) -> {
              return new class_1914(
                      new class_9306(ModItems.COPPER_COIN, 29),
                        Optional.empty(),
                        new class_1799(ModItems.HAKUREI_CANE),
                        7,
                        5,
                        0.13f
                );
            });
        });
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/entity/villager/Priest.java <==
package cc.thonly.reverie_dreams.entity.villager;

import cc.thonly.reverie_dreams.registry.content.item.RDItems;
import net.fabricmc.fabric.api.object.builder.v1.trade.TradeOfferHelper;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1887;
import net.minecraft.class_1893;
import net.minecraft.class_1914;
import net.minecraft.class_2378;
import net.minecraft.class_5455;
import net.minecraft.class_7924;
import net.minecraft.class_9306;
import java.util.Optional;

public class Priest {
    public static void registers() {
        TradeOfferHelper.registerVillagerOffers(RDVillagerProfessions.PRIEST, 1, factories -> {
            factories.add((entity, random) -> new class_1914(
                            new class_9306(RDItems.POWER, 11),
                            Optional.empty(),
                            new class_1799(RDItems.COPPER_COIN, 3),
                            7,
                            5,
                            0.2f
                    )
            );
            factories.add((entity, random) -> new class_1914(
                            new class_9306(RDItems.POINT, 12),
                            Optional.empty(),
                            new class_1799(RDItems.COPPER_COIN, 3),
                            7,
                            5,
                            0.13f
                    )
            );
        });
        TradeOfferHelper.registerVillagerOffers(RDVillagerProfessions.PRIEST, 2, factories -> {
            factories.add((entity, random) -> new class_1914(
                            new class_9306(RDItems.POWER, 38),
                            Optional.of(new class_9306(RDItems.COPPER_COIN, 24)),
                            new class_1799(RDItems.EXORCISM_PAPER, 6),
                            4,
                            5,
                            0.2f
                    )
            );
            factories.add((entity, random) -> {
                class_5455 registryManager = entity.method_56673();
                class_1799 woodenSwordStack = class_1802.field_8091.method_7854();
                class_2378<class_1887> lookup = registryManager.method_30530(class_7924.field_41265);
                woodenSwordStack.method_7978(lookup.method_47983(lookup.method_29107(class_1893.field_9123)), 4);
                woodenSwordStack.method_7978(lookup.method_47983(lookup.method_29107(class_1893.field_9119)), 2);
                return new class_1914(
                        new class_9306(RDItems.POINT, 29),
                        Optional.of(new class_9306(RDItems.COPPER_COIN, 31)),
                        woodenSwordStack,
                        7,
                        5,
                        0.13f
                );
            });
            factories.add((entity, random) -> {
              return new class_1914(
                      new class_9306(RDItems.COPPER_COIN, 29),
                        Optional.empty(),
                        new class_1799(RDItems.HAKUREI_CANE),
                        7,
                        5,
                        0.13f
                );
            });
        });
    }
}
